==> plugin-api-1.2.2-sources.jar: com/xebialabs/deployit/util/SingleTypeHandlingRunBook.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.util;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.ChangePlan;
import com.xebialabs.deployit.ChangeResolution;
import com.xebialabs.deployit.RunBook;
import com.xebialabs.deployit.Step;

public abstract class SingleTypeHandlingRunBook<T extends Serializable> implements RunBook {

	private Class<T> ciType;

	public SingleTypeHandlingRunBook(Class<T> ciType) {
		this.ciType = ciType;
	}

	@SuppressWarnings("unchecked")
	public Collection<ChangeResolution> resolve(ChangePlan changePlan) {
		Collection<ChangeResolution> crs = new ArrayList<ChangeResolution>();
		for (Change eachChange : changePlan.getChanges()) {
			if (eachChange.getConfigurationItemClass() == ciType) {
				List<Step> steps = new ArrayList<Step>();
				resolve(eachChange, changePlan, steps);
				if (!steps.isEmpty()) {
					ChangeResolution cr = new ChangeResolution(eachChange);
					cr.addSteps(steps);
					crs.add(cr);
				}
			}
		}
		return crs;
	}

	protected abstract void resolve(Change<T> change, ChangePlan changePlan, List<Step> steps);
}

==> plugin-api-1.3-sources.jar: com/xebialabs/deployit/util/SingleTypeHandlingRunBook.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.util;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.ChangePlan;
import com.xebialabs.deployit.ChangeResolution;
import com.xebialabs.deployit.RunBook;
import com.xebialabs.deployit.Step;

public abstract class SingleTypeHandlingRunBook<T extends Serializable> implements RunBook {

	private Class<T> ciType;

	public SingleTypeHandlingRunBook(Class<T> ciType) {
		this.ciType = ciType;
	}

	@SuppressWarnings("unchecked")
	public Collection<ChangeResolution> resolve(ChangePlan changePlan) {
		Collection<ChangeResolution> crs = new ArrayList<ChangeResolution>();
		for (Change<?> eachChange : changePlan.getChanges()) {
			if (eachChange.getConfigurationItemClass() == ciType) {
				List<Step> steps = new ArrayList<Step>();
				resolve((Change<T>) eachChange, changePlan, steps);
				if (!steps.isEmpty()) {
					ChangeResolution cr = new ChangeResolution(eachChange);
					cr.addSteps(steps);
					crs.add(cr);
				}
			}
		}
		return crs;
	}

	protected abstract void resolve(Change<T> change, ChangePlan changePlan, List<Step> steps);
}
